@@ -189,7 +189,12 @@ class Policy:
               for all dialogue turns in all training trackers
         """
         state_features, label_ids, entity_tags = self.featurizer.featurize_trackers(
-            training_trackers, domain, interpreter, bilou_tagging
+            training_trackers,
+            domain,
+            interpreter,
+            bilou_tagging,
+            ignore_action_unlikely_intent=self.supported_data()
+            == SupportedData.ML_DATA,
         )
 
         max_training_samples = kwargs.get("max_training_samples")
@@ -227,6 +232,8 @@ class Policy:
             use_text_for_last_user_input=use_text_for_last_user_input,
             ignore_rule_only_turns=self.supported_data() == SupportedData.ML_DATA,
             rule_only_data=self._rule_only_data,
+            ignore_action_unlikely_intent=self.supported_data()
+            == SupportedData.ML_DATA,
         )[0]
 
     def _featurize_for_prediction(
@@ -262,6 +269,8 @@ class Policy:
             use_text_for_last_user_input=use_text_for_last_user_input,
             ignore_rule_only_turns=self.supported_data() == SupportedData.ML_DATA,
             rule_only_data=self._rule_only_data,
+            ignore_action_unlikely_intent=self.supported_data()
+            == SupportedData.ML_DATA,
         )
 
     def train(
@@ -309,6 +318,7 @@ class Policy:
         is_end_to_end_prediction: bool = False,
         is_no_user_prediction: bool = False,
         diagnostic_data: Optional[Dict[Text, Any]] = None,
+        action_metadata: Optional[Dict[Text, Any]] = None,
     ) -> "PolicyPrediction":
         return PolicyPrediction(
             probabilities,
@@ -319,6 +329,7 @@ class Policy:
             is_end_to_end_prediction,
             is_no_user_prediction,
             diagnostic_data,
+            action_metadata=action_metadata,
         )
 
     def _metadata(self) -> Optional[Dict[Text, Any]]:
@@ -447,11 +458,13 @@ class Policy:
                     if PREVIOUS_ACTION in state:
                         if ACTION_NAME in state[PREVIOUS_ACTION]:
                             state_messages.append(
-                                f"previous action name: {str(state[PREVIOUS_ACTION][ACTION_NAME])}"
+                                f"previous action name: "
+                                f"{str(state[PREVIOUS_ACTION][ACTION_NAME])}"
                             )
                         if ACTION_TEXT in state[PREVIOUS_ACTION]:
                             state_messages.append(
-                                f"previous action text: {str(state[PREVIOUS_ACTION][ACTION_TEXT])}"
+                                f"previous action text: "
+                                f"{str(state[PREVIOUS_ACTION][ACTION_TEXT])}"
                             )
                     if ACTIVE_LOOP in state:
                         state_messages.append(f"active loop: {str(state[ACTIVE_LOOP])}")
@@ -478,6 +491,7 @@ class PolicyPrediction:
         is_no_user_prediction: bool = False,
         diagnostic_data: Optional[Dict[Text, Any]] = None,
         hide_rule_turn: bool = False,
+        action_metadata: Optional[Dict[Text, Any]] = None,
     ) -> None:
         """Creates a `PolicyPrediction`.
 
@@ -503,6 +517,8 @@ class PolicyPrediction:
                 fine-tuning purposes.
             hide_rule_turn: `True` if the prediction was made by the rules which
                 do not appear in the stories
+            action_metadata: Specifies additional metadata that can be passed
+                by policies.
         """
         self.probabilities = probabilities
         self.policy_name = policy_name
@@ -513,6 +529,7 @@ class PolicyPrediction:
         self.is_no_user_prediction = is_no_user_prediction
         self.diagnostic_data = diagnostic_data or {}
         self.hide_rule_turn = hide_rule_turn
+        self.action_metadata = action_metadata
 
     @staticmethod
     def for_action_name(
@@ -520,6 +537,7 @@ class PolicyPrediction:
         action_name: Text,
         policy_name: Optional[Text] = None,
         confidence: float = 1.0,
+        action_metadata: Optional[Dict[Text, Any]] = None,
     ) -> "PolicyPrediction":
         """Create a prediction for a given action.
 
@@ -528,13 +546,16 @@ class PolicyPrediction:
             action_name: The action which should be predicted.
             policy_name: The policy which did the prediction.
             confidence: The prediction confidence.
+            action_metadata: Additional metadata to be attached with the prediction.
 
         Returns:
             The prediction.
         """
         probabilities = confidence_scores_for(action_name, confidence, domain)
 
-        return PolicyPrediction(probabilities, policy_name)
+        return PolicyPrediction(
+            probabilities, policy_name, action_metadata=action_metadata
+        )
 
     def __eq__(self, other: Any) -> bool:
         """Checks if the two objects are equal.
@@ -557,6 +578,7 @@ class PolicyPrediction:
             and self.is_end_to_end_prediction == other.is_end_to_end_prediction
             and self.is_no_user_prediction == other.is_no_user_prediction
             and self.hide_rule_turn == other.hide_rule_turn
+            and self.action_metadata == other.action_metadata
             # We do not compare `diagnostic_data`, because it has no effect on the
             # action prediction.
         )
