@@ -96,20 +96,31 @@ class TrackerWithCachedStates(DialogueStateTracker):
         Returns:
             A list of states
         """
-        # we need to make sure this is the same domain, otherwise things will
-        # go wrong. but really, the same tracker shouldn't be used across
-        # domains
-        assert domain == self.domain
-
-        # if don't have it cached, we use the domain to calculate the states
-        # from the events
-        if self._states_for_hashing is None:
-            states = super().past_states(domain, omit_unset_slots=omit_unset_slots)
-            self._states_for_hashing = deque(
-                self.freeze_current_state(s) for s in states
+        if domain != self.domain:
+            raise ValueError(
+                "TrackerWithCachedStates cannot be used with a domain "
+                "that is different from the one it was created with."
             )
+        if omit_unset_slots:
+            # the tracker caches states with omit_unset_slots=False
+            # Retrieving them from cache with omit_unset_slots=True is not possible as
+            # this information is lost after a position in the event stream is turned
+            # into a state
+            states = super().past_states(domain, omit_unset_slots=omit_unset_slots)
+            states_for_hashing = deque(self.freeze_current_state(s) for s in states)
+        else:
+            # if don't have it cached, we use the domain to calculate the states
+            # from the events
+            # note: we ignore omit_unset_slots here as the cache was generated
+            # with the default value
+            states_for_hashing = self._states_for_hashing
+            if not states_for_hashing:
+                states = super().past_states(domain)
+                states_for_hashing = deque(self.freeze_current_state(s) for s in states)
 
-        return self._states_for_hashing
+            self._states_for_hashing = states_for_hashing
+
+        return states_for_hashing
 
     @staticmethod
     def _unfreeze_states(frozen_states: Deque[FrozenState]) -> List[State]:
@@ -189,11 +200,9 @@ class TrackerWithCachedStates(DialogueStateTracker):
             self._states_for_hashing.append(frozen_state)
 
     def update(self, event: Event, skip_states: bool = False) -> None:
-        """Modify the state of the tracker according to an ``Event``. """
-
+        """Modify the state of the tracker according to an ``Event``."""
         # if `skip_states` is `True`, this function behaves exactly like the
         # normal update of the `DialogueStateTracker`
-
         if self._states_for_hashing is None and not skip_states:
             # rest of this function assumes we have the previous state
             # cached. let's make sure it is there.
